@@ -12,7 +12,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tk.h,v 1.30.2.2 1999/10/30 09:35:56 hobbs Exp $
+ * RCS: @(#) $Id: tk.h,v 1.38 2000/02/08 11:31:32 hobbs Exp $
  */
 
 #ifndef _TK
@@ -25,31 +25,32 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-    
+
 /*
  * When version numbers change here, you must also go into the following files
  * and update the version numbers:
  *
+ * library/tk.tcl	(only if Major.minor changes, not patchlevel)
  * unix/configure.in
- * README
  * win/configure.in
- * win/makefile.vc	(only if major.minor changes, not patchlevel)
- * library/tk.tcl	(only if major.minor changes, not patchlevel)
- * mac/README		(only if major.minor changes, not patchlevel)
- * win/README		(only if major.minor changes, not patchlevel)
- * unix/README		(only if major.minor changes, not patchlevel)
-
+ * win/makefile.vc	(not patchlevel)
+ * README
+ * mac/README		(not patchlevel)
+ * win/README		(not patchlevel)
+ * unix/README		(not patchlevel)
+ * win/aclocal.m4	(not patchlevel)
+ *
  * You may also need to update some of these files when the numbers change
  * for the version of Tcl that this release of Tk is compiled against.
  */
 
 #define TK_MAJOR_VERSION   8
-#define TK_MINOR_VERSION   2
+#define TK_MINOR_VERSION   3
 #define TK_RELEASE_LEVEL   TCL_FINAL_RELEASE
-#define TK_RELEASE_SERIAL  2
+#define TK_RELEASE_SERIAL  0
 
-#define TK_VERSION "8.2"
-#define TK_PATCH_LEVEL "8.2.2+"
+#define TK_VERSION	"8.3"
+#define TK_PATCH_LEVEL	"8.3.0+"
 
 /*
  * The following definitions set up the proper options for Macintosh
@@ -203,6 +204,7 @@ typedef struct Tk_OptionSpec {
  */
 
 #define TK_OPTION_NULL_OK		1
+#define TK_OPTION_DONT_SET_DEFAULT	8
 
 /*
  * Macro to use to fill in "offset" fields of the Tk_OptionSpec.
@@ -830,7 +832,7 @@ typedef struct Tk_Item  {
 					 * in list are drawn just below earlier
 					 * ones. */
     Tk_State state;			/* state of item */
-    char *updateCmd;			/* for "-updatecommand" option */
+    char *reserved1;			/* reserved for future use */
     int redraw_flags;			/* some flags used in the canvas */
 
     /*
@@ -856,57 +858,23 @@ typedef struct Tk_Item  {
 #define TK_ITEM_STATE_DEPENDANT		1
 #define TK_ITEM_DONT_REDRAW		2
 
-/*
- * Structures used for implementing visitors.
- */
-
-typedef ClientData Tk_VisitorStartProc _ANSI_ARGS_((Tcl_Interp *interp,
-		   Tk_Canvas canvas, int argc, Tcl_Obj *CONST *objv));
-typedef int 	Tk_VisitorItemProc _ANSI_ARGS_((Tcl_Interp *interp,
-		   Tk_Canvas canvas, ClientData clientData,
-		   Tk_Item *itemPtr));
-typedef int 	Tk_VisitorEndProc _ANSI_ARGS_((Tcl_Interp *interp,
-		   Tk_Canvas canvas, ClientData clientData));
-
-typedef struct Tk_VisitorType {
-    char *name;
-    int typeSize;			/* should be sizeof(Tk_VisitorType) */
-    int flags;				/* If this flag is non-zero then
-					 * the item needs to be redrawn. */
-    Tk_VisitorStartProc *startProc;
-    Tk_VisitorEndProc  *endProc;
-    Tk_VisitorItemProc *visitArc;	/* The Arc visitor procedure. */
-    Tk_VisitorItemProc *visitBitmap;	/* The Bitmap visitor procedure. */
-    Tk_VisitorItemProc *visitImage;	/* The Image visitor procedure. */
-    Tk_VisitorItemProc *visitLine;	/* The Line visitor procedure. */
-    Tk_VisitorItemProc *visitOval;	/* The Oval visitor procedure. */
-    Tk_VisitorItemProc *visitPolygon;	/* The Polygon visitor procedure. */
-    Tk_VisitorItemProc *visitRectangle;	/* The Rectangle visitor procedure. */
-    Tk_VisitorItemProc *visitText;	/* The Text visitor procedure. */
-    Tk_VisitorItemProc *visitWindow;	/* The Window visitor procedure. */
-    Tk_VisitorItemProc *visitSticker;	/* The Sticker visitor procedure.
-					 * from tkSticker*/
-    Tk_VisitorItemProc *visitViewport;	/* The Viewport visitor procedure.
-					 * from TkSM */
-    Tk_VisitorItemProc *visitBarchart;	/* The Barchart visitor procedure.
-					 * from Scotty */
-    Tk_VisitorItemProc *visitStripchart;/* The Stripchart visitor procedure.
-					 * from Scotty */
-
-    /*
-     *------------------------------------------------------------------
-     * Starting here is additional item-extension stuff;
-     * you can add extra item types after this plus other information.
-     *------------------------------------------------------------------
-     */
-} Tk_VisitorType;
-
 /*
  * Records of the following type are used to describe a type of
  * item (e.g.  lines, circles, etc.) that can form part of a
  * canvas widget.
  */
 
+#ifdef USE_OLD_CANVAS
+typedef int	Tk_ItemCreateProc _ANSI_ARGS_((Tcl_Interp *interp,
+		    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
+		    char **argv));
+typedef int	Tk_ItemConfigureProc _ANSI_ARGS_((Tcl_Interp *interp,
+		    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
+		    char **argv, int flags));
+typedef int	Tk_ItemCoordProc _ANSI_ARGS_((Tcl_Interp *interp,
+		    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
+		    char **argv));
+#else
 typedef int	Tk_ItemCreateProc _ANSI_ARGS_((Tcl_Interp *interp,
 		    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
 		    Tcl_Obj *CONST objv[]));
@@ -916,6 +884,7 @@ typedef int	Tk_ItemConfigureProc _ANSI_ARGS_((Tcl_Interp *interp,
 typedef int	Tk_ItemCoordProc _ANSI_ARGS_((Tcl_Interp *interp,
 		    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
 		    Tcl_Obj *CONST argv[]));
+#endif
 typedef void	Tk_ItemDeleteProc _ANSI_ARGS_((Tk_Canvas canvas,
 		    Tk_Item *itemPtr, Display *display));
 typedef void	Tk_ItemDisplayProc _ANSI_ARGS_((Tk_Canvas canvas,
@@ -944,23 +913,6 @@ typedef void	Tk_ItemInsertProc _ANSI_ARGS_((Tk_Canvas canvas,
 		    Tk_Item *itemPtr, int beforeThis, char *string));
 typedef void	Tk_ItemDCharsProc _ANSI_ARGS_((Tk_Canvas canvas,
 		    Tk_Item *itemPtr, int first, int last));
-typedef void	Tk_ItemBboxProc _ANSI_ARGS_((Tk_Canvas canvas,
-		    Tk_Item *itemPtr));
-typedef int	Tk_ItemGetCoordProc _ANSI_ARGS_((Tk_Item *itemPtr,
-		    double **coordsPtr, Tcl_FreeProc *freeProc));
-typedef int	Tk_ItemSetCoordProc _ANSI_ARGS_((Tk_Canvas canvas,
-		    Tk_Item *itemPtr, int num, double *coords));
-
-/*
- * Some flag values that can be used in the "flags" field in Tk_ItemType.
- */
-
-#define TK_ITEM_ALWAYS_REDRAW 1
-#define TK_ITEM_VISITOR_SUPPORT 2
-
-/*
- * Structures used for implementing visitors.
- */
 
 #ifndef __NO_OLD_CONFIG
 
@@ -982,9 +934,9 @@ typedef struct Tk_ItemType {
 					 * this type. */
     Tk_ItemDisplayProc *displayProc;	/* Procedure to display items of
 					 * this type. */
-    int flags;				/* TK_ITEM_TYPE_ALWAYS_REDRAW means displayProc
-					 * should be called even when the item has
-					 * been moved off-screen. */
+    int alwaysRedraw;			/* Non-zero means displayProc should
+					 * be called even when the item has
+  					 * been moved off-screen. */
     Tk_ItemPointProc *pointProc;	/* Computes distance from item to
 					 * a given point. */
     Tk_ItemAreaProc *areaProc;		/* Computes whether item is inside,
@@ -1011,14 +963,10 @@ typedef struct Tk_ItemType {
 					 * from an item. */
     struct Tk_ItemType *nextPtr;	/* Used to link types together into
 					 * a list. */
-    Tk_ItemBboxProc *bboxProc;		/* Procedure to calculate the bounding
-					 * box for an item. */
-    int acceptProc;			/* Offset of visitors function  in
-					 * tkVisitorType struct for this item. */
-    Tk_ItemGetCoordProc *getCoordProc;	/* Procedure to get the coordinates
-					 * for an item. */
-    Tk_ItemSetCoordProc *setCoordProc;	/* Procedure to set the coordinates
-					 * for an item. */
+    char *reserved1;			/* Reserved for future extension. */
+    int   reserved2;			/* Carefully compatible with */
+    char *reserved3;			/* Jan Nijtmans dash patch */
+    char *reserved4;
 } Tk_ItemType;
 
 #endif
@@ -1099,8 +1047,6 @@ typedef struct Tk_TSOffset {
 #define TK_OFFSET_MIDDLE	64
 #define TK_OFFSET_BOTTOM	128
 
-typedef struct Tk_Tile_ *Tk_Tile;	/* Opaque type for tiles */
-
 typedef struct Tk_Outline {
     GC gc;			/* Graphics context. */
     double width;		/* Width of outline. */
@@ -1110,10 +1056,10 @@ typedef struct Tk_Outline {
     Tk_Dash dash;		/* Dash pattern */
     Tk_Dash activeDash;		/* Dash pattern if state is active*/
     Tk_Dash disabledDash;	/* Dash pattern if state is disabled*/
-    Tk_Tile tile;		/* Tile pattern */
-    Tk_Tile activeTile;		/* Tile pattern if state is active*/
-    Tk_Tile disabledTile;	/* Tile pattern if state is disabled*/
-    Tk_TSOffset tsoffset;	/* tile/stipple offset for outline*/
+    VOID *reserved1;		/* reserved for future expansion */
+    VOID *reserved2;
+    VOID *reserved3;
+    Tk_TSOffset tsoffset;	/* stipple offset for outline*/
     XColor *color;		/* Outline color. */
     XColor *activeColor;	/* Outline color if state is active. */
     XColor *disabledColor;	/* Outline color if state is disabled. */
@@ -1122,46 +1068,6 @@ typedef struct Tk_Outline {
     Pixmap disabledStipple;	/* Outline Stipple pattern if state is disabled. */
 } Tk_Outline;
 
-/*
- * Some functions handy for Dashing and Outlines (in tkCanvUtil.c).
- */
-
-EXTERN int	Tk_GetDash _ANSI_ARGS_((Tcl_Interp *interp,
-		    CONST char *value, Tk_Dash *dash));
-EXTERN void	Tk_CreateOutline _ANSI_ARGS_((Tk_Outline *outline));
-EXTERN void	Tk_DeleteOutline _ANSI_ARGS_((Display *display,
-		    Tk_Outline *outline));
-EXTERN int	Tk_ConfigOutlineGC _ANSI_ARGS_((XGCValues *gcValues,
-		    Tk_Canvas canvas ,Tk_Item *item,
-		    Tk_Outline *outline));
-EXTERN int	Tk_ChangeOutlineGC _ANSI_ARGS_((Tk_Canvas canvas,
-		    Tk_Item *item, Tk_Outline *outline));
-EXTERN int	Tk_ResetOutlineGC _ANSI_ARGS_((Tk_Canvas canvas,
-		    Tk_Item *item, Tk_Outline *outline));
-EXTERN int	Tk_CanvasPsOutline _ANSI_ARGS_((Tk_Canvas canvas,
-		    Tk_Item *item, Tk_Outline *outline));
-
-/*
- * Some functions handy for Tiling and Stipple/Tile offset.
- */
-
-typedef void	(Tk_TileChangedProc) _ANSI_ARGS_((ClientData clientData,
-		    Tk_Tile tile, Tk_Item *itemPtr));
-EXTERN Tk_Tile	Tk_GetTile _ANSI_ARGS_((Tcl_Interp *interp, Tk_Window tkwin,
-		    CONST char *imageName));
-EXTERN void	Tk_FreeTile _ANSI_ARGS_((Tk_Tile tile));
-EXTERN char *	Tk_NameOfTile _ANSI_ARGS_((Tk_Tile tile));
-EXTERN void	Tk_SetTileChangedProc _ANSI_ARGS_((Tk_Tile tile,
-		    Tk_TileChangedProc * changeProc, ClientData clientData,
-		    Tk_Item *itemPtr));
-EXTERN Pixmap	Tk_PixmapOfTile _ANSI_ARGS_((Tk_Tile tile));
-EXTERN void	Tk_SizeOfTile _ANSI_ARGS_((Tk_Tile tile, int *widthPtr,
-		    int *heightPtr));
-EXTERN void	Tk_SetTileOrigin _ANSI_ARGS_((Tk_Window tkwin, GC gc, int x,
-		    int y));
-EXTERN void	Tk_SetTileCanvasItem _ANSI_ARGS_((Tk_Tile tile,
-			    Tk_Canvas canvas, Tk_Item *itemPtr));
-
 
 /*
  *--------------------------------------------------------------
@@ -1291,23 +1197,22 @@ typedef int (Tk_ImageStringWriteProc) _ANSI_ARGS_((Tcl_Interp *interp,
 	Tk_PhotoImageBlock *blockPtr));
 #else
 typedef int (Tk_ImageFileMatchProc) _ANSI_ARGS_((Tcl_Channel chan,
-	char *fileName, Tcl_Obj *format, int *widthPtr,
+	CONST char *fileName, Tcl_Obj *format, int *widthPtr,
 	int *heightPtr, Tcl_Interp *interp));
 typedef int (Tk_ImageStringMatchProc) _ANSI_ARGS_((Tcl_Obj *dataObj,
 	Tcl_Obj *format, int *widthPtr, int *heightPtr,
 	Tcl_Interp *interp));
 typedef int (Tk_ImageFileReadProc) _ANSI_ARGS_((Tcl_Interp *interp,
-	Tcl_Channel chan, char *fileName, Tcl_Obj *format,
+	Tcl_Channel chan, CONST char *fileName, Tcl_Obj *format,
 	Tk_PhotoHandle imageHandle, int destX, int destY,
 	int width, int height, int srcX, int srcY));
 typedef int (Tk_ImageStringReadProc) _ANSI_ARGS_((Tcl_Interp *interp,
 	Tcl_Obj *dataObj, Tcl_Obj *format, Tk_PhotoHandle imageHandle,
 	int destX, int destY, int width, int height, int srcX, int srcY));
 typedef int (Tk_ImageFileWriteProc) _ANSI_ARGS_((Tcl_Interp *interp,
-	char *fileName, Tcl_Obj *format, Tk_PhotoImageBlock *blockPtr));
+	CONST char *fileName, Tcl_Obj *format, Tk_PhotoImageBlock *blockPtr));
 typedef int (Tk_ImageStringWriteProc) _ANSI_ARGS_((Tcl_Interp *interp,
-	Tcl_DString *dataPtr, Tcl_Obj *format,
-	Tk_PhotoImageBlock *blockPtr));
+	Tcl_Obj *format, Tk_PhotoImageBlock *blockPtr));
 #endif
 
 /*
@@ -1344,14 +1249,14 @@ struct Tk_PhotoImageFormat {
 				 * by image format handler. */
 };
 
-EXTERN void		Tk_CreateImageType _ANSI_ARGS_((
-				Tk_ImageType * typePtr));
-EXTERN void		Tk_CreatePhotoImageFormat _ANSI_ARGS_((
-				Tk_PhotoImageFormat * formatPtr));
+EXTERN void		Tk_CreateOldImageType _ANSI_ARGS_((
+				Tk_ImageType *typePtr));
+EXTERN void		Tk_CreateOldPhotoImageFormat _ANSI_ARGS_((
+				Tk_PhotoImageFormat *formatPtr));
 
-#ifndef USE_OLD_IMAGE
-#define Tk_CreateImageType Tk_CreateNewImageType
-#define Tk_CreatePhotoImageFormat Tk_CreateNewPhotoImageFormat
+#if !defined(USE_TK_STUBS) && defined(USE_OLD_IMAGE)
+#define Tk_CreateImageType Tk_CreateOldImageType
+#define Tk_CreatePhotoImageFormat Tk_CreateOldPhotoImageFormat
 #endif
 
 
@@ -1404,6 +1309,23 @@ EXTERN void		Tk_CreatePhotoImageFormat _ANSI_ARGS_((
 #define Tk_Main(argc, argv, proc) \
     Tk_MainEx(argc, argv, proc, Tcl_CreateInterp())
 
+char *Tk_InitStubs _ANSI_ARGS_((Tcl_Interp *interp, char *version, int exact));
+
+#ifndef USE_TK_STUBS
+
+#define Tk_InitStubs(interp, version, exact) \
+    Tcl_PkgRequire(interp, "Tk", version, exact)
+
+#endif
+
+void Tk_InitImageArgs _ANSI_ARGS_((Tcl_Interp *interp, int argc, char ***argv));
+
+#if !defined(USE_TK_STUBS) || !defined(USE_OLD_IMAGE)
+
+#define Tk_InitImageArgs(interp, argc, argv) /**/
+
+#endif
+
 
 /*
  *--------------------------------------------------------------
@@ -1427,6 +1349,7 @@ typedef Tk_RestrictAction (Tk_RestrictProc) _ANSI_ARGS_((
 typedef int (Tk_SelectionProc) _ANSI_ARGS_((ClientData clientData,
 	int offset, char *buffer, int maxBytes));
 
+
 /*
  *--------------------------------------------------------------
  *
@@ -1437,67 +1360,6 @@ typedef int (Tk_SelectionProc) _ANSI_ARGS_((ClientData clientData,
 
 #include "tkDecls.h"
 
-/*
- *--------------------------------------------------------------
- *
- * Exported procedures introduced by dash-patch.
- *
- *--------------------------------------------------------------
- */
-
-EXTERN int		Tk_CanvasGetCoordFromObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Canvas canvas, Tcl_Obj *obj,
-			    double *doublePtr));
-EXTERN void		Tk_CanvasSetOffset _ANSI_ARGS_((
-			    Tk_Canvas canvas, GC gc, Tk_TSOffset *offset));
-EXTERN void		Tk_CreatePhotoOption _ANSI_ARGS_((Tcl_Interp *interp,
-			    CONST char *name, Tcl_CmdProc *proc));
-EXTERN void		Tk_DitherPhoto _ANSI_ARGS_((Tk_PhotoHandle handle,
-			    int x, int y, int width, int height));
-EXTERN int		Tk_PostscriptBitmap _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, Tk_PostscriptInfo psInfo,
-			    Pixmap bitmap, int startX, int startY,
-			    int width, int height));
-EXTERN int		Tk_PostscriptColor _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_PostscriptInfo psInfo, XColor *colorPtr));
-EXTERN int		Tk_PostscriptFont _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_PostscriptInfo psInfo, Tk_Font font));
-EXTERN int		Tk_PostscriptImage _ANSI_ARGS_((Tk_Image image,
-			    Tcl_Interp *interp, Tk_Window tkwin,
-			    Tk_PostscriptInfo psinfo, int x, int y,
-			    int width, int height, int prepass));
-EXTERN void		Tk_PostscriptPath _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_PostscriptInfo psInfo, double *coordPtr,
-			    int numPoints));
-EXTERN int		Tk_PostscriptStipple _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, Tk_PostscriptInfo psInfo,
-			    Pixmap bitmap));
-EXTERN double		Tk_PostscriptY _ANSI_ARGS_((double y,
-			    Tk_PostscriptInfo psInfo));
-
-/*
- * Convenience declaration of Tk_InitStubs.
- * This function is not *implemented* by the tcl library, so the storage
- * class is neither DLLEXPORT nor DLLIMPORT
- */
-
-#undef TCL_STORAGE_CLASS
-#define TCL_STORAGE_CLASS
-
-EXTERN char *Tk_InitStubs _ANSI_ARGS_((Tcl_Interp *interp, char *version, int exact));
-
-#ifndef USE_TK_STUBS
-
-#define Tk_InitStubs(interp, version, exact) \
-    Tcl_PkgRequire(interp, "Tk", version, exact)
-
-#endif
-
-/*
- * Tcl commands exported by Tk:
- */
-
-
 #endif /* RESOURCE_INCLUDED */
 
 #undef TCL_STORAGE_CLASS
