@@ -11,13 +11,30 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkEvent.c,v 1.5 1999/08/13 17:52:12 redman Exp $
+ * RCS: @(#) $Id: tkEvent.c,v 1.7 1999/12/16 21:57:36 hobbs Exp $
  */
 
+#define reserved188 tcl_MainLoop
+#define reserved284 tcl_SetMainLoop
+
 #include "tkPort.h"
 #include "tkInt.h"
 #include <signal.h>
 
+#ifndef USE_TCL_STUBS
+extern TclStubs tclStubs;
+#define tclStubsPtr (&tclStubs)
+#endif
+
+/*
+ * Make sure that Tcl_MainLoop always references the stub pointer, not
+ * the real function.
+ */
+#undef Tcl_MainLoop
+#define Tcl_MainLoop ((void (*) _ANSI_ARGS_((void))) ((tclStubsPtr)->tcl_MainLoop))
+#undef Tcl_SetMainLoop
+#define Tcl_SetMainLoop ((void (*) _ANSI_ARGS_((VOID *))) ((tclStubsPtr)->tcl_SetMainLoop))
+
 /*
  * There's a potential problem if a handler is deleted while it's
  * current (i.e. its procedure is executing), since Tk_HandleEvent
@@ -681,19 +698,20 @@ Tk_HandleEvent(eventPtr)
      * input context for the window if it hasn't already been done
      * (XFilterEvent needs this context).
      */
-
-    if (!(winPtr->flags & TK_CHECKED_IC)) {
-	if (winPtr->dispPtr->inputMethod != NULL) {
-	    winPtr->inputContext = XCreateIC(
+    if (winPtr->dispPtr->useInputMethods) {
+	if (!(winPtr->flags & TK_CHECKED_IC)) {
+	    if (winPtr->dispPtr->inputMethod != NULL) {
+		winPtr->inputContext = XCreateIC(
 		    winPtr->dispPtr->inputMethod, XNInputStyle,
 		    XIMPreeditNothing|XIMStatusNothing,
 		    XNClientWindow, winPtr->window,
 		    XNFocusWindow, winPtr->window, NULL);
+	    }
+	    winPtr->flags |= TK_CHECKED_IC;
+	}
+	if (XFilterEvent(eventPtr, None)) {
+	    goto done;
 	}
-	winPtr->flags |= TK_CHECKED_IC;
-    }
-    if (XFilterEvent(eventPtr, None)) {
-        goto done;
     }
 #endif /* I18N_IMPROVE */
 #endif /* TK_USE_INPUT_METHODS */
@@ -1155,6 +1173,7 @@ void
 Tk_MainLoop()
 {
     if (Tcl_MainLoop) {
+	Tcl_SetMainLoop(Tk_GetNumMainWindows);
 	Tcl_MainLoop();
 	return;
     }
