@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkMacAppInit.c,v 1.9 1999/04/28 18:18:07 redman Exp $
+ * RCS: @(#) $Id: tkMacAppInit.c,v 1.12 2000/02/10 08:53:06 jingham Exp $
  */
 
 #undef TCL_USE_STUBS
@@ -25,6 +25,7 @@
 #include "tk.h"
 #include "tkInt.h"
 #include "tkMacInt.h"
+#include "tclInt.h"
 #include "tclMac.h"
 
 #ifdef TK_TEST
@@ -97,6 +98,15 @@ main(
     argc = 1;
     newArgv[0] = "Wish";
     newArgv[1] = NULL;
+    
+    /* Tk_Main is actually #defined to 
+     *     Tk_MainEx(argc, argv, Tcl_AppInit, Tcl_CreateInterp())
+     * Unfortunately, you also HAVE to call Tcl_FindExecutable
+     * BEFORE creating the first interp, or the tcl_library will not
+     * get set properly.  So we call it by hand here...
+     */
+    
+    Tcl_FindExecutable(newArgv[0]);
     Tk_Main(argc, newArgv, Tcl_AppInit);
 }
 
@@ -242,7 +252,11 @@ MacintoshInit()
 
     InitGraf(&tcl_macQdPtr->thePort);
     InitFonts();
+    if (TkMacHaveAppearance() >= 0x110) {
+        InitFloatingWindows();
+    } else {
     InitWindows();
+    }
     InitMenus();
     InitDialogs((long) NULL);		
     InitCursor();
@@ -274,7 +288,6 @@ MacintoshInit()
 
 
     Tcl_MacSetEventProc(TkMacConvertEvent);
-
     return TCL_OK;
 }
 
