@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkWinX.c,v 1.5 1999/04/16 01:51:54 stanton Exp $
+ * RCS: @(#) $Id: tkWinX.c,v 1.7 1999/11/19 22:00:19 hobbs Exp $
  */
 
 #include "tkWinInt.h"
@@ -19,13 +19,13 @@
  * The zmouse.h file includes the definition for WM_MOUSEWHEEL.
  */
 
-#define WM_MOUSEWHEEL (WM_MOUSELAST+1)
+#include <zmouse.h>
 
 /*
  * Definitions of extern variables supplied by this file.
  */
 
-int tkpIsWin32s = -1;
+static int tkPlatformId;
 
 /*
  * Declarations of static variables used in this file.
@@ -142,7 +142,7 @@ TkWinXInit(hInstance)
 
     info.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
     GetVersionEx(&info);
-    tkpIsWin32s = (info.dwPlatformId == VER_PLATFORM_WIN32s);
+    tkPlatformId = info.dwPlatformId;
 
     if (childClassInitialized != 0) {
 	return;
@@ -516,7 +516,6 @@ TkWinChildProc(hwnd, message, wParam, lParam)
 
 	case WM_CREATE:
 	case WM_ERASEBKGND:
-	case WM_WINDOWPOSCHANGED:
 	    result = 0;
 	    break;
 
@@ -1131,3 +1130,30 @@ TkpGetMS()
 {
     return GetTickCount();
 }
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * TkWinGetPlatformId --
+ *
+ *	Determines whether running under NT, 95, or Win32s, to allow 
+ *	runtime conditional code.
+ *
+ * Results:
+ *	The return value is one of:
+ *	    VER_PLATFORM_WIN32s		Win32s on Windows 3.1. 
+ *	    VER_PLATFORM_WIN32_WINDOWS	Win32 on Windows 95.
+ *	    VER_PLATFORM_WIN32_NT	Win32 on Windows NT
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+int		
+TkWinGetPlatformId()
+{
+    return tkPlatformId;
+}
+
