@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: winMain.c,v 1.7.6.1 1999/11/03 00:43:09 hobbs Exp $
+ * RCS: @(#) $Id: winMain.c,v 1.9 1999/12/02 02:05:46 redman Exp $
  */
 
 #undef TCL_USE_STUBS
@@ -41,12 +41,24 @@ extern int		Tktest_Init(Tcl_Interp *interp);
 #endif /* TK_TEST */
 
 #ifdef TCL_TEST
-extern int		Objtest_Init _ANSI_ARGS_((Tcl_Interp *interp));
 extern int		Tcltest_Init _ANSI_ARGS_((Tcl_Interp *interp));
 #endif /* TCL_TEST */
 
 static BOOL consoleRequired = TRUE;
 
+    /*
+     * The following #if block allows you to change the AppInit
+     * function by using a #define of TCL_LOCAL_APPINIT instead
+     * of rewriting this entire file.  The #if checks for that
+     * #define and uses Tcl_AppInit if it doesn't exist.
+     */
+    
+#ifndef TK_LOCAL_APPINIT
+#define TK_LOCAL_APPINIT Tcl_AppInit    
+#endif
+    extern int TK_LOCAL_APPINIT _ANSI_ARGS_((Tcl_Interp *interp));
+
+
 
 /*
  *----------------------------------------------------------------------
@@ -65,6 +77,7 @@ static BOOL consoleRequired = TRUE;
  *----------------------------------------------------------------------
  */
 
+
 int APIENTRY
 WinMain(hInstance, hPrevInstance, lpszCmdLine, nCmdShow)
     HINSTANCE hInstance;
@@ -74,17 +87,21 @@ WinMain(hInstance, hPrevInstance, lpszCmdLine, nCmdShow)
 {
     char **argv;
     int argc;
+    char buffer[MAX_PATH+1];
+    char *p;
+    
+    /*
+     * The following #if block allows you to change how Tcl finds the startup
+     * script, prime the library or encoding paths, fiddle with the argv,
+     * etc., without needing to rewrite Tk_Main()
+     */
+    
+#ifdef TK_LOCAL_MAIN_HOOK
+    extern int TK_LOCAL_MAIN_HOOK _ANSI_ARGS_((int *argc, char ***argv));
+#endif
 
     Tcl_SetPanicProc(WishPanic);
 
-    /*
-     * Set up the default locale to be standard "C" locale so parsing
-     * is performed correctly.
-     */
-
-    setlocale(LC_ALL, "C");
-    setargv(&argc, &argv);
-
     /*
      * Increase the application queue size from default value of 8.
      * At the default value, cross application SendMessage of WM_KILLFOCUS
@@ -103,7 +120,32 @@ WinMain(hInstance, hPrevInstance, lpszCmdLine, nCmdShow)
 
     consoleRequired = TRUE;
 
-    Tk_Main(argc, argv, Tcl_AppInit);
+    /*
+     * Set up the default locale to be standard "C" locale so parsing
+     * is performed correctly.
+     */
+
+    setlocale(LC_ALL, "C");
+    setargv(&argc, &argv);
+
+    /*
+     * Replace argv[0] with full pathname of executable, and forward
+     * slashes substituted for backslashes.
+     */
+
+    GetModuleFileName(NULL, buffer, sizeof(buffer));
+    argv[0] = buffer;
+    for (p = buffer; *p != '\0'; p++) {
+	if (*p == '\\') {
+	    *p = '/';
+	}
+    }
+
+#ifdef TK_LOCAL_MAIN_HOOK
+    TK_LOCAL_MAIN_HOOK(&argc, &argv);
+#endif
+
+    Tk_Main(argc, argv, TK_LOCAL_APPINIT);
     return 1;
 }
 
@@ -156,11 +198,6 @@ Tcl_AppInit(interp)
     }
     Tcl_StaticPackage(interp, "Tcltest", Tcltest_Init,
             (Tcl_PackageInitProc *) NULL);
-    if (Objtest_Init(interp) == TCL_ERROR) {
-	return TCL_ERROR;
-    }
-    Tcl_StaticPackage(interp, "Objtest", Objtest_Init,
-            (Tcl_PackageInitProc *) NULL);
 #endif /* TCL_TEST */
 
 #ifdef TK_TEST
@@ -217,7 +254,6 @@ WishPanic TCL_VARARGS_DEF(CONST char *,arg1)
 #endif
     ExitProcess(1);
 }
-
 /*
  *-------------------------------------------------------------------------
  *
@@ -334,6 +370,7 @@ setargv(argcPtr, argvPtr)
     *argcPtr = argc;
     *argvPtr = argv;
 }
+
 
 /*
  *----------------------------------------------------------------------
